#region MigraDoc - Creating Documents on the Fly
//
// Authors:
//   Stefan Lange
//   Klaus Potzesny
//   David Stephensen
//
// Copyright (c) 2001-2017 empira Software GmbH, Cologne Area (Germany)
//
// http://www.pdfsharp.com
// http://www.migradoc.com
// http://sourceforge.net/projects/pdfsharp
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
#endregion

using System;

// ReSharper disable InconsistentNaming

namespace MigraDoc.DocumentObjectModel.publics
{
    /// <summary>
    /// Indicates that this field can be accessed via SetValue and GetValue.
    /// </summary>
    [AttributeUsage(AttributeTargets.Field | AttributeTargets.Property)]
    public class DVAttribute : Attribute
    {
        /// <summary>
        /// Initializes a new instance of the DVAttribute class.
        /// </summary>
        public DVAttribute()
        {
            RefOnly = false;
            ItemType = null;
        }

        /// <summary>
        /// Gets or sets the type of the reflected value. Must be specified by NEnum.
        /// </summary>
        public Type Type
        {
            get { return _type; }
            set { _type = value; }
        }
        Type _type;

        /// <summary>
        /// Determines whether the field is RefOnly and should be excluded from recursive operations.
        /// </summary>
        public bool RefOnly;

        // TODO: Check type in value descriptor
        /// <summary>
        /// Describes the type of the elements a collection contains.
        /// </summary>
        public Type ItemType;
    }
}
